==> biz-tool-1.1.30-sources.jar: cn/com/duiba/biz/tool/duiba/mq/PluginTakeOrder.java <==
package cn.com.duiba.biz.tool.duiba.mq;

import java.io.Serializable;

/**
 * ClassName:PluginTakeOrder<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: mq 消息 接受对象
 * @date 创建时间：2018/5/10  10:07
 * @since JDK 1.8
 **/
public class PluginTakeOrder implements Serializable {

    private static final long serialVersionUID = -955910395854462125L;
    private String orderNum;
    private Long activityOptionId;
    private String activityOptionName;
    private String activityOptionType;
    private String activityOptionFacePrice;
    private Long appItemId;
    private Long itemId;
    private Long gid;
    private String gtype;
    private Long couponId;
    private String mainOrderNum;
    private Integer exchangeStatus;//交易状态  1  待领取    2 领奖成功

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Long getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionId(Long activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public String getActivityOptionType() {
        return activityOptionType;
    }

    public void setActivityOptionType(String activityOptionType) {
        this.activityOptionType = activityOptionType;
    }

    public String getActivityOptionFacePrice() {
        return activityOptionFacePrice;
    }

    public void setActivityOptionFacePrice(String activityOptionFacePrice) {
        this.activityOptionFacePrice = activityOptionFacePrice;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public String getGtype() {
        return gtype;
    }

    public void setGtype(String gtype) {
        this.gtype = gtype;
    }

    public Long getCouponId() {
        return couponId;
    }

    public void setCouponId(Long couponId) {
        this.couponId = couponId;
    }

    public String getMainOrderNum() {
        return mainOrderNum;
    }

    public void setMainOrderNum(String mainOrderNum) {
        this.mainOrderNum = mainOrderNum;
    }

    public Integer getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(Integer exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }
}

==> biz-tool-1.2.25-sources.jar: cn/com/duiba/biz/tool/duiba/mq/PluginTakeOrder.java <==
package cn.com.duiba.biz.tool.duiba.mq;

import java.io.Serializable;

/**
 * ClassName:PluginTakeOrder<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: mq 消息 接受对象
 * @date 创建时间：2018/5/10  10:07
 * @since JDK 1.8
 **/
public class PluginTakeOrder implements Serializable {

    private static final long serialVersionUID = -955910395854462125L;
    private String orderNum;
    private Long activityOptionId;
    private String activityOptionName;
    private String activityOptionType;
    private String activityOptionFacePrice;
    private Long appItemId;
    private Long itemId;
    private Long gid;
    private String gtype;
    private Long couponId;
    private String mainOrderNum;
    private Integer exchangeStatus;//交易状态  1  待领取    2 领奖成功
    /** 开发者订单id */
    private String bizId;

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Long getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionId(Long activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public String getActivityOptionType() {
        return activityOptionType;
    }

    public void setActivityOptionType(String activityOptionType) {
        this.activityOptionType = activityOptionType;
    }

    public String getActivityOptionFacePrice() {
        return activityOptionFacePrice;
    }

    public void setActivityOptionFacePrice(String activityOptionFacePrice) {
        this.activityOptionFacePrice = activityOptionFacePrice;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public String getGtype() {
        return gtype;
    }

    public void setGtype(String gtype) {
        this.gtype = gtype;
    }

    public Long getCouponId() {
        return couponId;
    }

    public void setCouponId(Long couponId) {
        this.couponId = couponId;
    }

    public String getMainOrderNum() {
        return mainOrderNum;
    }

    public void setMainOrderNum(String mainOrderNum) {
        this.mainOrderNum = mainOrderNum;
    }

    public Integer getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(Integer exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }

    public String getBizId() {
        return bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }
}
